*******
Used By
*******

Below are papers, presentations, and other material that use *pyDeltaRCM*. 

.. important:: 

    This is not a comprehensive list!

Papers
------
.. copied from "Chicago" style within Google Scholar

[4] Moodie, Andrew J., and Timothy A. Goudge. “Fluvial Reworking Eliminates Small Craters, but Does Not Meaningfully Bias the Mars Interbedded‐crater Record.” Journal of Geophysical Research: Planets 130, no. 3 (March 2025). https://doi.org/10.1029/2023je008183. 

[3] Hariharan, Jayaram, Kyle Wright, Andrew Moodie, Nelson Tull, and Paola Passalacqua. 2023. “Impacts of Human Modifications on Material Transport in Deltas.” Earth Surface Dynamics 11 (3): 405–27. https://doi.org/10.5194/esurf-11-405-2023.

[2] Hariharan, Jayaram, Paola Passalacqua, Zhongyuan Xu, Holly A. Michael, Elisabeth Steel, Austin Chadwick, Chris Paola, and Andrew J. Moodie. "Modeling the Dynamic Response of River Deltas to Sea‐Level Rise Acceleration." Journal of Geophysical Research: Earth Surface 127, no. 9 (2022): e2022JF006762. https://doi.org/10.1029/2022JF006762.

[1] Moodie, Andrew J., and Paola Passalacqua. "When Does Faulting‐Induced Subsidence Drive Distributary Network Reorganization?." Geophysical Research Letters 48, no. 22 (2021): e2021GL095053. https://doi.org/10.1029/2021GL095053.


Presentations
-------------



Other
-----

[1] Hariharan, Jayaram. "Exploring *pyDeltaRCM*: A Collection of Numerical Experiments." Zenodo v0.1 (2022), https://zenodo.org/records/7315646.